@@ -78,7 +78,7 @@ else:
     )
 
 if installation.TYPE == installation.TYPES.SYSTEM:
-    PORTAGE_BIN_PATH = """/usr/lib/portage/python3.11"""
+    PORTAGE_BIN_PATH = """/usr/lib/portage/python3.14"""
 else:
     PORTAGE_BIN_PATH = f"{PORTAGE_BASE_PATH}/bin"
 
@@ -183,7 +183,6 @@ SUPPORTED_FEATURES = frozenset(
         "distlocks",
         "downgrade-backup",
         "ebuild-locks",
-        "export-pms-vars",
         "fail-clean",
         "fakeroot",
         "fixlafiles",
@@ -194,6 +193,7 @@ SUPPORTED_FEATURES = frozenset(
         "icecream",
         "installsources",
         "ipc-sandbox",
+        "jobserver-token",
         "keeptemp",
         "keepwork",
         "lmirror",
@@ -213,6 +213,7 @@ SUPPORTED_FEATURES = frozenset(
         "noman",
         "nostrip",
         "notitles",
+        "packdebug",
         "parallel-fetch",
         "parallel-install",
         "pid-sandbox",
@@ -253,7 +254,7 @@ SUPPORTED_FEATURES = frozenset(
     )
 )
 
-EAPI = 8
+EAPI = 9
 
 HASHING_BLOCKSIZE = 32768
 
